@@ -25,25 +25,14 @@
 #include <jack/ringbuffer.h>
 #include "sourceclient.h"
 #include "main.h"
-
-typedef jack_default_audio_sample_t sample_t;
+#include "audio_feed.h"
 
 static struct audio_feed *audio_feed;
 
-int audio_feed_process_audio(jack_nframes_t n_frames, void *arg)
+void audio_feed_supply_audio(sample_t *lc, sample_t *rc, jack_nframes_t n_frames)
     {
     struct audio_feed *self = audio_feed;
     struct threads_info *ti = self->threads_info;
-    sample_t *input_port_buffer[2], *monitor_buffer[2];
-    int i;
-
-    input_port_buffer[0] = jack_port_get_buffer(g.port.output_in_l, n_frames);
-    input_port_buffer[1] = jack_port_get_buffer(g.port.output_in_r, n_frames);
-    monitor_buffer[0] = jack_port_get_buffer(g.port.monitor_output_in_l, n_frames);
-    monitor_buffer[1] = jack_port_get_buffer(g.port.monitor_output_in_r, n_frames);
-
-    for (int i = 0; i < 2; ++i)
-        memcpy(monitor_buffer[i], input_port_buffer[i], n_frames * sizeof (sample_t));
 
     void process(struct audio_feed_data *afdata)
         {
@@ -59,8 +48,18 @@ int audio_feed_process_audio(jack_nframes_t n_frames, void *arg)
                         goto reevaluate;
                 }
 
-                jack_ringbuffer_write(afdata->input_rb[0], (char *)input_port_buffer[0], n_frames * sizeof (sample_t));
-                jack_ringbuffer_write(afdata->input_rb[1], (char *)input_port_buffer[1], n_frames * sizeof (sample_t));
+                if (self->random_noise_f) {
+                    sample_t noise;
+
+                    for (int i = 0; i < n_frames; ++i)
+                        for (int j = 0; j < 2; ++j) {
+                            noise = (((sample_t)(rand() % 200)) - 100.0f) / 2000.0f;
+                            jack_ringbuffer_write(afdata->input_rb[j], (char *)&noise, sizeof (sample_t));
+                        }
+                } else {
+                    jack_ringbuffer_write(afdata->input_rb[0], (char *)lc, n_frames * sizeof (sample_t));
+                    jack_ringbuffer_write(afdata->input_rb[1], (char *)rc, n_frames * sizeof (sample_t));
+                }
                 break;
             case JD_FLUSH:
                 jack_ringbuffer_reset(afdata->input_rb[0]);
@@ -72,13 +71,11 @@ int audio_feed_process_audio(jack_nframes_t n_frames, void *arg)
             }
         }
 
-    for (i = 0; i < ti->n_encoders; i++)
+    for (int i = 0; i < ti->n_encoders; i++)
         process(&(ti->encoder[i]->afdata));
 
-    for (i = 0; i < ti->n_recorders; i++)
+    for (int i = 0; i < ti->n_recorders; i++)
         process(&(ti->recorder[i]->afdata));
-
-    return 0;
     }
 
 int audio_feed_jack_samplerate_request(struct threads_info *ti, struct universal_vars *uv, void *param)
@@ -105,9 +102,20 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
     return self;
     }
 
-
 void audio_feed_destroy(struct audio_feed *self)
     {
     self->threads_info->audio_feed = NULL;
     free(self);
     }
+
+int audio_feed_random_noise_on(struct threads_info *ti, struct universal_vars *uv, void *param)
+    {
+    audio_feed->random_noise_f = 1;
+    return SUCCEEDED;
+    }
+
+int audio_feed_random_noise_off(struct threads_info *ti, struct universal_vars *uv, void *param)
+    {
+    audio_feed->random_noise_f = 0;
+    return SUCCEEDED;
+    }
