@@ -23,41 +23,29 @@
 
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
-
-#ifdef HAVE_SWRESAMPLE
 #include <libswresample/swresample.h>
-#endif
 
 #include "xlplayer.h"
 #include "mp3tagread.h"
 
 struct avcodecdecode_vars
     {
-    AVCodec *codec;
+    const AVCodec *codec;
     AVPacket pkt;
     AVPacket pktcopy;
     AVCodecContext *c;
     AVFormatContext *ic;
+    AVChannelLayout out_ch_layout;
     int size;
     int resample;
     unsigned int stream;
-#ifdef HAVE_AVCODEC_SEND_PACKET
     AVFrame af;
-#else
-    AVFrame *frame;
-#endif
     float drop;
     struct mp3taginfo taginfo;
     struct chapter *current_chapter;
     int channels;   /* number of downmixed channels 1 or 2 */
-
-#ifdef HAVE_SWRESAMPLE
     SwrContext *swr;
     uint8_t *floatsamples;
-#else
-    float *floatsamples;
-#endif
-
     };
 
 int avcodecdecode_reg(struct xlplayer *xlplayer);
