@@ -28,6 +28,7 @@
 #include <jack/ringbuffer.h>
 #include "sourceclient.h"
 #include "sig.h"
+#include "live_test1_encoder.h"
 #include "live_ogg_encoder.h"
 #include "live_mp3_encoder.h"
 #include "live_mp2_encoder.h"
@@ -35,7 +36,7 @@
 #include "live_oggspeex_encoder.h"
 #include "live_oggopus_encoder.h"
 #include "live_webm_encoder.h"
-#include "live_aac_encoder.h"
+#include "live_aac_encoder2.h"
 #include "bsdcompat.h"
 #include "main.h"
 #ifdef DYN_LAME
@@ -65,12 +66,25 @@ int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *
     return SUCCEEDED;
     }
 
-static struct encoder_data_format encoder_lex_format(char *source, char *family, char *codec)
+int encoder_aac_profiles(struct threads_info *ti, struct universal_vars *uv, void *param)
+{
+    fprintf(g.out, "idjcsc: aac_profiles=");
+#ifdef HAVE_AVCODEC
+    live_aac_encoder2_profiles(g.out);
+#endif
+    fputc('\n', g.out);
+    fflush(g.out);
+    if (ferror(g.out))
+        return FAILED;
+    return SUCCEEDED;
+}
+
+static struct encoder_data_format encoder_lex_format(char *source, char *family, char *codec, char *profile)
     {
     struct encoder_data_format df = {
         .source = ENCODER_SOURCE_UNHANDLED,
         .family = ENCODER_FAMILY_UNHANDLED,
-        .codec = ENCODER_CODEC_UNHANDLED
+        .codec = ENCODER_CODEC_UNHANDLED,
         };
 
     void warning(char *msg, char *setting)
@@ -84,6 +98,12 @@ static struct encoder_data_format encoder_lex_format(char *source, char *family,
     if (!strcmp(source, "file"))
         df.source = ENCODER_SOURCE_FILE;
 
+    if (!strcmp(family, "dummy"))
+        df.family = ENCODER_FAMILY_DUMMY;
+
+    if (!strcmp(codec, "test1"))
+        df.codec = ENCODER_CODEC_TEST1;
+
     if (!strcmp(family, "mpeg"))
         df.family = ENCODER_FAMILY_MPEG;
 
@@ -99,11 +119,12 @@ static struct encoder_data_format encoder_lex_format(char *source, char *family,
     if (!strcmp(codec, "mp2"))
         df.codec = ENCODER_CODEC_MP2;
 
-    if (!strcmp(codec, "aac"))
-        df.codec = ENCODER_CODEC_AAC;
-
-    if (!strcmp(codec, "aacpv2"))
-        df.codec = ENCODER_CODEC_AACPLUSV2;
+    if (!strcmp(codec, "aac")) {
+        if (!strcmp(profile, "HE-AAC") || !strcmp(profile, "HE-AACv2"))
+            df.codec = ENCODER_CODEC_AACPLUS;
+        else
+            df.codec = ENCODER_CODEC_AAC;
+    }
 
     if (!strcmp(codec, "vorbis"))
         df.codec = ENCODER_CODEC_VORBIS;
@@ -162,10 +183,10 @@ static void encoder_free_resampler(struct encoder *self)
     int i;
 
     for (i = 0; i < 2; i++)
-        if (self->src_state[i])
+        if (self->iswr_state[i])
             {
-            src_delete(self->src_state[i]);
-            self->src_state[i] = NULL;
+            iswr_delete(self->iswr_state[i]);
+            self->iswr_state[i] = NULL;
             }
     }
 
@@ -312,14 +333,14 @@ struct encoder_ip_data *encoder_get_input_data(struct encoder *encoder, size_t m
         if (encoder->n_channels == 2)
             {
             encoder->rs_channel = 0;
-            id->qty_samples = (size_t)src_callback_read(encoder->src_state[0], encoder->sr_conv_ratio, samples_available, id->buffer[0]);
+            id->qty_samples = (size_t)iswr_callback_read(encoder->iswr_state[0], encoder->sr_conv_ratio, samples_available, id->buffer[0]);
             encoder->rs_channel = 1;
-            src_callback_read(encoder->src_state[1], encoder->sr_conv_ratio, id->qty_samples, id->buffer[1]);
+            iswr_callback_read(encoder->iswr_state[1], encoder->sr_conv_ratio, id->qty_samples, id->buffer[1]);
             }
         else
             {
             encoder->rs_channel = -1;
-            id->qty_samples = (size_t)src_callback_read(encoder->src_state[0], encoder->sr_conv_ratio, samples_available, id->buffer[0]);
+            id->qty_samples = (size_t)iswr_callback_read(encoder->iswr_state[0], encoder->sr_conv_ratio, samples_available, id->buffer[0]);
             }
         if (id->qty_samples == 0)
             goto no_data;
@@ -566,7 +587,7 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
         goto failed;
         }
 
-    self->data_format = encoder_lex_format(ev->encode_source, ev->family, ev->codec);
+    self->data_format = encoder_lex_format(ev->encode_source, ev->family, ev->codec, ev->profile);
 
     switch (self->data_format.source) {
         case ENCODER_SOURCE_JACK:
@@ -593,6 +614,15 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
                     }
                     break;
 #endif
+                case ENCODER_FAMILY_DUMMY:
+                    switch (self->data_format.codec) {
+                        case ENCODER_CODEC_TEST1:
+                            encoder_init = live_test1_encoder_init;
+                            break;
+                        default:
+                            goto failed;
+                        }
+                    break;
 
                 case ENCODER_FAMILY_MPEG:
                     switch (self->data_format.codec) {
@@ -605,9 +635,13 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
 #endif
                             break;
                         case ENCODER_CODEC_AAC:
-                        case ENCODER_CODEC_AACPLUSV2:
-#if defined(HAVE_AVCODEC) && defined(HAVE_AVFORMAT)
-                            encoder_init = live_aac_encoder_init;
+#if defined(HAVE_AVCODEC)
+                            encoder_init = live_aac_encoder2_init;
+#endif
+                            break;
+                        case ENCODER_CODEC_AACPLUS:
+#if defined(HAVE_AVCODEC)
+                            encoder_init = live_aac_encoder2_init;
 #endif
                             break;
                         case ENCODER_CODEC_UNHANDLED:
@@ -679,9 +713,9 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
         resample_mode = encoder_get_resample_mode(ev->resample_quality);
         for (i = 0; i < self->n_channels; i++)
             {
-            if (!(self->src_state[i] = src_callback_new(encoder_resampler_get_data, resample_mode, 1, &error, self)))
+            if (!(self->iswr_state[i] = iswr_callback_new(encoder_resampler_get_data, resample_mode, 1, &error, self)))
                 goto failed;
-            src_set_ratio(self->src_state[i], self->sr_conv_ratio);
+            iswr_set_ratio(self->iswr_state[i], self->sr_conv_ratio);
             }
         }
     else
