@@ -26,11 +26,12 @@
 #include <jack/ringbuffer.h>
 #include <pthread.h>
 #include "sourceclient.h"
+#include "iswr.h"
 
 enum performance_warning { PW_OK, PW_AUDIO_DATA_DROPPED };
 enum encoder_source {ENCODER_SOURCE_UNHANDLED, ENCODER_SOURCE_JACK, ENCODER_SOURCE_FILE};
-enum encoder_family {ENCODER_FAMILY_UNHANDLED, ENCODER_FAMILY_MPEG, ENCODER_FAMILY_OGG, ENCODER_FAMILY_WEBM};
-enum encoder_codec {ENCODER_CODEC_UNHANDLED, ENCODER_CODEC_MP3, ENCODER_CODEC_VORBIS, ENCODER_CODEC_FLAC, ENCODER_CODEC_SPEEX, ENCODER_CODEC_OPUS, ENCODER_CODEC_MP2, ENCODER_CODEC_AAC, ENCODER_CODEC_AACPLUSV2};
+enum encoder_family {ENCODER_FAMILY_UNHANDLED, ENCODER_FAMILY_MPEG, ENCODER_FAMILY_OGG, ENCODER_FAMILY_WEBM, ENCODER_FAMILY_DUMMY};
+enum encoder_codec {ENCODER_CODEC_UNHANDLED, ENCODER_CODEC_MP3, ENCODER_CODEC_VORBIS, ENCODER_CODEC_FLAC, ENCODER_CODEC_SPEEX, ENCODER_CODEC_OPUS, ENCODER_CODEC_MP2, ENCODER_CODEC_AAC, ENCODER_CODEC_AACPLUS, ENCODER_CODEC_TEST1};
 enum encoder_state { ES_STOPPED, ES_STARTING, ES_RUNNING, ES_STOPPING, ES_PAUSED };
 enum packet_flags {     PF_UNSET    = 0x00,
                                 PF_INITIAL  = 0x01,
@@ -41,8 +42,9 @@ enum packet_flags {     PF_UNSET    = 0x00,
                                 PF_HEADER   = 0x20,
                                 PF_MP2      = 0x40,
                                 PF_AAC      = 0x80,
-                                PF_AACP2    = 0x100,
-                                PF_WEBM     = 0x200 };
+                                PF_AACP    = 0x100,
+                                PF_WEBM     = 0x200,
+                                PF_DUMMY    = 0X400 };
 
 struct encoder_vars
     {
@@ -51,6 +53,7 @@ struct encoder_vars
     char *resample_quality;
     char *family;
     char *codec;
+    char *profile;
     char *bitrate;
     char *variability;
     char *bitwidth;
@@ -144,7 +147,7 @@ struct encoder
     long samplerate;
     long target_samplerate;
     double sr_conv_ratio;
-    SRC_STATE *src_state[2];     /* resampler variables */
+    SRC_STATE *iswr_state[2];     /* resampler variables */
     float *rs_input[2];          /* buffer used by resampler input callback */
     int rs_channel;              /* resampler callback channel control */
     int resample_f;              /* true or false to resampling required */
@@ -171,6 +174,7 @@ struct encoder
 
 struct encoder *encoder_init(struct threads_info *ti, int numeric_id);
 int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *param);
+int encoder_aac_profiles(struct threads_info *ti, struct universal_vars *uv, void *param);
 void encoder_destroy(struct encoder *self);
 struct encoder_op_packet *encoder_client_get_packet(struct encoder_op *op);
 void encoder_client_free_packet(struct encoder_op_packet *packet);
@@ -185,7 +189,7 @@ int encoder_initiate_fade(struct threads_info *ti, struct universal_vars *uv, vo
 int encoder_update(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_song_metadata(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_custom_metadata(struct threads_info *ti, struct universal_vars *uv, void *other);
-void encoder_src_data_cleanup(struct encoder *self);
+//void encoder_src_data_cleanup(struct encoder *self);
 struct encoder_ip_data *encoder_get_input_data(struct encoder *encoder, size_t min_samples_needed, size_t max_samples, float **caller_supplied_buffer);
 void encoder_ip_data_free(struct encoder_ip_data *id);
 #endif
