@@ -32,7 +32,7 @@ static void id3_frame_extra_cleanup(struct id3_frame *frame)
     if (!strcmp(frame->frame_header.frame_id, "TLEN"))
         return;
     if (frame->frame_header.frame_id[0] == 'T' && strcmp(frame->frame_header.frame_id, "TXXX"))
-        { 
+        {
         free(tdptr->text);
         return;
         }
@@ -82,11 +82,11 @@ void id3_tag_destroy(struct id3_tag *tag)
 static int id3_syncsafe_int(uint32_t value, uint32_t *ssvalue)
     {
     unsigned char *ssint = (unsigned char *)ssvalue;
-    
-    ssint[0] = (value >> 21) & 0xFF;
-    ssint[1] = (value >> 14) & 0xFF;
-    ssint[2] = (value >> 7 ) & 0xFF;
-    ssint[3] = (value >> 0 ) & 0xFF;
+
+    ssint[0] = (value >> 21) & 0x7F;
+    ssint[1] = (value >> 14) & 0x7F;
+    ssint[2] = (value >> 7 ) & 0x7F;
+    ssint[3] = (value >> 0 ) & 0x7F;
     return *ssvalue;
     }
 
@@ -104,7 +104,7 @@ static int id3_compile_text_frame(struct id3_frame *ptr, int embedded_size)
     char *body;
     int body_size;
     uint32_t ssint;
-    
+
     if (embedded_size != 0)
         {
         fprintf(stderr, "id3_compile_text_frame: WARNING: text frames do not support frame embedding\n");
@@ -133,7 +133,7 @@ static int id3_compile_numeric_frame(struct id3_frame *ptr, int embedded_size)
     char *body;
     int body_size;
     uint32_t ssint;
-    
+
     if (embedded_size != 0)
         {
         fprintf(stderr, "id3_compile_text_frame: WARNING: text frames do not support frame embedding\n");
@@ -165,7 +165,7 @@ static int id3_compile_chap_frame(struct id3_frame *ptr, int embedded_size)
     char *body, *bptr;
     int body_size, text_size;
     uint32_t ssint;
-    
+
     dptr = ptr->data;
     if (!(body = bptr = malloc(body_size = 17 + (text_size = strlen(dptr->identifier)) + embedded_size)))
         {
@@ -194,7 +194,7 @@ static int id3_compile_chap_frame(struct id3_frame *ptr, int embedded_size)
 static int id3_compile_frames(struct id3_frame *ptr)
     {
     int embedded_size = 0, chained_size = 0;
-    
+
     if (ptr->first_embedded_frame)
         embedded_size = id3_compile_frames(ptr->first_embedded_frame);
     if (ptr->next)
@@ -231,7 +231,7 @@ void id3_compile(struct id3_tag *tag)
     int chained_size;
     uint32_t ssint;
     char *wp;
-    
+
     fflush(g.out);
     ptr = tag->first_frame;
     if (ptr)
@@ -272,7 +272,7 @@ struct id3_frame *id3_numeric_string_frame_new(char *identifier, int value)
     {
     struct id3_frame *frame;
     char string[20];
-    
+
     if (!(frame = calloc(1, sizeof (struct id3_frame))))
         {
         fprintf(stderr, "id3_text_frame_new: malloc failure\n");
@@ -288,7 +288,7 @@ struct id3_frame *id3_text_frame_new(char *identifier, char *text, unsigned char
     {
     struct id3_frame *frame;
     struct id3_text_frame_data *tframe_data;
-    
+
     if (!(frame = calloc(1, sizeof (struct id3_frame))))
         {
         fprintf(stderr, "id3_text_frame_new: malloc failure\n");
@@ -335,7 +335,7 @@ struct id3_frame *id3_chap_frame_new(char *unique_id, uint32_t start_ms, uint32_
 struct id3_tag *id3_tag_new(int flags, int padding)
     {
     struct id3_tag *tag;
-    
+
     if (!(tag = calloc(1, sizeof (struct id3_tag))))
         {
         fprintf(stderr, "id3_tag_new: malloc failure\n");
