@@ -34,26 +34,26 @@ typedef jack_default_audio_sample_t sample_t;
 static void live_mp3_packetize_metadata(struct encoder *e, struct lm3e_data * const s)
     {
     size_t l = 4;
-    
+
     pthread_mutex_lock(&e->metadata_mutex);
-    
+
     l += strlen(e->custom_meta);
     l += strlen(e->artist);
     l += strlen(e->title);
     l += strlen(e->album);
-    
+
     if ((s->metadata = realloc(s->metadata, l)))
         snprintf(s->metadata, l, "%s\n%s\n%s\n%s", e->custom_meta, e->artist, e->title, e->album);
     else
         fprintf(stderr, "malloc failure\n");
-        
+
     e->new_metadata = FALSE;
     pthread_mutex_unlock(&e->metadata_mutex);
     }
 
 static int live_mp3_write_packet(struct encoder *encoder, struct lm3e_data *s, unsigned char *buffer, size_t buffersize, int flags)
     {
-    struct encoder_op_packet packet;
+    struct encoder_op_packet_rb_feed packet;
 
     packet.header.bit_rate = encoder->bitrate;
     packet.header.sample_rate = encoder->target_samplerate;
@@ -80,7 +80,7 @@ static void live_mp3_encoder_main(struct encoder *encoder)
             fprintf(stderr, "live_mp3_encoder_main: malloc failure\n");
             goto bailout;
             }
-            
+
         if (!(s->gfp = lame_init()))
             {
             fprintf(stderr, "live_mp3_encoder_main: failed to initialise LAME\n");
