@@ -28,6 +28,8 @@
 #include <jack/session.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <linux/prctl.h>
+#include <sys/prctl.h>
 
 #ifdef HAVE_LIBAV
 #include <libavcodec/avcodec.h>
@@ -127,6 +129,12 @@ static void session_callback(jack_session_event_t *event, void *arg)
 
 static int buffer_size_callback(jack_nframes_t n_frames, void *arg)
     {
+    static jack_nframes_t prev;
+
+    if (n_frames <= prev)  /* prevent buffer shrinkage */
+        return 0;
+
+    prev = n_frames;
     return mixer_new_buffer_size(n_frames);
     }
 
@@ -172,18 +180,6 @@ static void cleanup_jack()
         }
     }
 
-static int main_process_audio(jack_nframes_t n_frames, void *arg)
-    {
-    int rv;
-
-    rv =  mixer_process_audio(n_frames, arg) || audio_feed_process_audio(n_frames, arg);
-
-    if (rv == 0)
-        g.jack_timeout = 0;
-
-    return rv;
-    }
-
 static jack_port_t *port_register(const char *name, const char *type, int flags) {
     jack_port_t *port;
 
@@ -200,12 +196,15 @@ static int backend_main()
     size_t n = 10;
     int keep_running = TRUE;
     jack_options_t options = 0;
+    char client_id[7];
 
-    /* Without these being set the backend will segfault. */
+    sprintf(client_id, "%d", rand() % 100000);
+    /* Without these being set the back-end will segfault. */
         {
         int o = FALSE;    /* Overwrite flag */
         if (setenv("session_type", "L0", o) ||
-                setenv("client_id", "idjc_nofrontend", o) ||
+                setenv("app_name", "idjc", o) ||
+                setenv("client_id", client_id, o) ||
                 setenv("mic_qty", "4", o) ||
                 setenv("num_streamers", "6", o) ||
                 setenv("num_encoders", "6", o) ||
@@ -268,7 +267,7 @@ static int backend_main()
     #define CHK_ZERO(it) do { int ec; if ((ec = it)) { fprintf(g.out, "%s failed with error code %d\n", #it, ec); fflush(g.out); exit(5); } } while(FALSE)
 
     CHK_ZERO(jack_set_freewheel_callback(g.client, freewheel_callback, NULL));
-    CHK_ZERO(jack_set_process_callback(g.client, main_process_audio, NULL));
+    CHK_ZERO(jack_set_process_callback(g.client, mixer_process_audio, NULL));
     CHK_ZERO(jack_set_buffer_size_callback(g.client, buffer_size_callback, NULL));
     CHK_ZERO(jack_set_port_connect_callback(g.client, port_connect_callback, NULL));
     CHK_ZERO(jack_set_port_registration_callback(g.client, port_registration_callback, NULL));
@@ -394,7 +393,7 @@ static int backend_main()
         }
     }
 
-    fprintf(g.out, "idjc backend ready\n");
+    fprintf(g.out, "idjc back-end ready\n");
     fflush(g.out);
 
     alarm(1);
@@ -449,15 +448,22 @@ int init_backend(int *read_pipe, int *write_pipe)
 
     if (!(pid = fork()))
         {
-        int maxfd = sysconf(_SC_OPEN_MAX);
+            {
+            /* Pipewire ignores these at time of writing. */
+            setenv("PIPEWIRE_APPLICATION_NAME_HINT", PACKAGE_NAME, 1);
+            if (prctl(PR_SET_NAME, PACKAGE_NAME, NULL, NULL, NULL))
+                fprintf(stderr, "prctl PR_SET_NAME failed\n");
+            else
+                setenv("PIPEWIRE_USE_PR_GET_NAME_HINT", "1", 1);
+            }
 
+        int maxfd = sysconf(_SC_OPEN_MAX);
         for (int fd = 3; fd < maxfd; ++fd)
             close(fd);
 
         if ((g.in = fopen(ui2be, "r")) && (g.out = fopen(be2ui, "w")))
             {
             fputc('#', g.out);
-
             int ret = backend_main();
             fclose(g.in);
             fclose(g.out);
