@@ -50,6 +50,8 @@ struct jack_ports
     jack_port_t *pe1_out_r;
     jack_port_t *pe2_out_l;
     jack_port_t *pe2_out_r;
+    jack_port_t *pe3_out_l;
+    jack_port_t *pe3_out_r;
     jack_port_t *pl_in_l;
     jack_port_t *pl_in_r;
     jack_port_t *pr_in_l;
@@ -58,12 +60,16 @@ struct jack_ports
     jack_port_t *pi_in_r;
     jack_port_t *pe_in_l;
     jack_port_t *pe_in_r;
-    
+
     jack_port_t *midi_port;
-        
+
     /* streamer/recorder capture ports */
     jack_port_t *output_in_l;
     jack_port_t *output_in_r;
+
+    /* monitors for capture ports */
+    jack_port_t *monitor_output_in_l;
+    jack_port_t *monitor_output_in_r;
     };
 
 struct globs
@@ -72,7 +78,9 @@ struct globs
     int main_timeout;          /* Inactive when negative. */
     int jack_timeout;
     int has_head;
+    int extant_port_check;
     int mixer_up;
+    int dsp_conn_count;
     jack_client_t *client;     /* Client handle to JACK. */
     struct jack_ports port;    /* JACK port handles. */
     jack_ringbuffer_t *session_event_rb; /* Session event buffer */
