@@ -54,6 +54,7 @@
 #include "peakfilter.h"
 #include "sig.h"
 #include "main.h"
+#include "audio_feed.h"
 
 /* playlength of ring buffer contents in seconds */
 #define MAIN_RB_SIZE 10.0
@@ -459,7 +460,7 @@ static void update_smoothed_volumes()
     }
 
 /* process_audio: the JACK callback routine */
-int mixer_process_audio(jack_nframes_t nframes, void *arg)
+int mixer_process_audio(jack_nframes_t n_frames, void *arg)
     {
     int samples_todo;   /* The samples remaining counter in the main loop */
     float df;           /* main player ducking factor */
@@ -476,6 +477,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
     /* pointers to buffers provided by JACK */
     sample_t *aap, *lap, *rap, *lsp, *rsp, *lpsp, *rpsp, *lprp, *rprp;
     sample_t *al_buffer, *la_buffer, *ra_buffer, *ls_buffer, *rs_buffer, *lps_buffer, *rps_buffer;
+    sample_t *ol_buffer, *or_buffer, *mol_buffer, *mor_buffer;
     sample_t *dolp, *dorp, *dilp, *dirp;
     sample_t *plolp, *plorp, *prolp, *prorp, *piolp, *piorp;
     sample_t *pe1olp, *pe1orp, *pe2olp, *pe2orp, *pe3olp, *pe3orp;
@@ -494,7 +496,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
     float e_ls, e_rs, e1_ls, e1_rs, e2_ls, e2_rs, e3_ls, e3_rs;
 
     /* midi_control. read incoming commands forward to gui */
-    midi_buffer = jack_port_get_buffer(g.port.midi_port, nframes);
+    midi_buffer = jack_port_get_buffer(g.port.midi_port, n_frames);
     midi_nevents = jack_midi_get_event_count(midi_buffer);
     if (midi_nevents!=0)
         {
@@ -551,52 +553,61 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
     {
         struct jack_ports *p = &g.port;
 
-        al_buffer = aap = (sample_t *) jack_port_get_buffer(p->alarm_out, nframes);
-        la_buffer = lap = (sample_t *) jack_port_get_buffer(p->dj_out_l, nframes);
-        ra_buffer = rap = (sample_t *) jack_port_get_buffer(p->dj_out_r, nframes);
-        ls_buffer = lsp = (sample_t *) jack_port_get_buffer(p->str_out_l, nframes);
-        rs_buffer = rsp = (sample_t *) jack_port_get_buffer(p->str_out_r, nframes);
-        lps_buffer = lpsp = (sample_t *) jack_port_get_buffer(p->voip_out_l, nframes);
-        rps_buffer = rpsp = (sample_t *) jack_port_get_buffer(p->voip_out_r, nframes);
-        lprp = (sample_t *) jack_port_get_buffer(p->voip_in_l, nframes);
-        rprp = (sample_t *) jack_port_get_buffer(p->voip_in_r, nframes);
-        dolp = (sample_t *) jack_port_get_buffer(p->dsp_out_l, nframes);
-        dorp = (sample_t *) jack_port_get_buffer(p->dsp_out_r, nframes);
-        dilp = (sample_t *) jack_port_get_buffer(p->dsp_in_l, nframes);
-        dirp = (sample_t *) jack_port_get_buffer(p->dsp_in_r, nframes);
-        plolp = (sample_t *) jack_port_get_buffer(p->pl_out_l, nframes);
-        plorp = (sample_t *) jack_port_get_buffer(p->pl_out_r, nframes);
-        prolp = (sample_t *) jack_port_get_buffer(p->pr_out_l, nframes);
-        prorp = (sample_t *) jack_port_get_buffer(p->pr_out_r, nframes);
-        piolp = (sample_t *) jack_port_get_buffer(p->pi_out_l, nframes);
-        piorp = (sample_t *) jack_port_get_buffer(p->pi_out_r, nframes);
-        pe1olp = (sample_t *) jack_port_get_buffer(p->pe1_out_l, nframes);
-        pe1orp = (sample_t *) jack_port_get_buffer(p->pe1_out_r, nframes);
-        pe2olp = (sample_t *) jack_port_get_buffer(p->pe2_out_l, nframes);
-        pe2orp = (sample_t *) jack_port_get_buffer(p->pe2_out_r, nframes);
-        pe3olp = (sample_t *) jack_port_get_buffer(p->pe3_out_l, nframes);
-        pe3orp = (sample_t *) jack_port_get_buffer(p->pe3_out_r, nframes);
-        plilp = (sample_t *) jack_port_get_buffer(p->pl_in_l, nframes);
-        plirp = (sample_t *) jack_port_get_buffer(p->pl_in_r, nframes);
-        prilp = (sample_t *) jack_port_get_buffer(p->pr_in_l, nframes);
-        prirp = (sample_t *) jack_port_get_buffer(p->pr_in_r, nframes);
-        piilp = (sample_t *) jack_port_get_buffer(p->pi_in_l, nframes);
-        piirp = (sample_t *) jack_port_get_buffer(p->pi_in_r, nframes);
-        peilp = (sample_t *) jack_port_get_buffer(p->pe_in_l, nframes);
-        peirp = (sample_t *) jack_port_get_buffer(p->pe_in_r, nframes);
+        al_buffer = aap = (sample_t *) jack_port_get_buffer(p->alarm_out, n_frames);
+        la_buffer = lap = (sample_t *) jack_port_get_buffer(p->dj_out_l, n_frames);
+        ra_buffer = rap = (sample_t *) jack_port_get_buffer(p->dj_out_r, n_frames);
+        ls_buffer = lsp = (sample_t *) jack_port_get_buffer(p->str_out_l, n_frames);
+        rs_buffer = rsp = (sample_t *) jack_port_get_buffer(p->str_out_r, n_frames);
+        lps_buffer = lpsp = (sample_t *) jack_port_get_buffer(p->voip_out_l, n_frames);
+        rps_buffer = rpsp = (sample_t *) jack_port_get_buffer(p->voip_out_r, n_frames);
+        lprp = (sample_t *) jack_port_get_buffer(p->voip_in_l, n_frames);
+        rprp = (sample_t *) jack_port_get_buffer(p->voip_in_r, n_frames);
+        dolp = (sample_t *) jack_port_get_buffer(p->dsp_out_l, n_frames);
+        dorp = (sample_t *) jack_port_get_buffer(p->dsp_out_r, n_frames);
+        dilp = (sample_t *) jack_port_get_buffer(p->dsp_in_l, n_frames);
+        dirp = (sample_t *) jack_port_get_buffer(p->dsp_in_r, n_frames);
+        plolp = (sample_t *) jack_port_get_buffer(p->pl_out_l, n_frames);
+        plorp = (sample_t *) jack_port_get_buffer(p->pl_out_r, n_frames);
+        prolp = (sample_t *) jack_port_get_buffer(p->pr_out_l, n_frames);
+        prorp = (sample_t *) jack_port_get_buffer(p->pr_out_r, n_frames);
+        piolp = (sample_t *) jack_port_get_buffer(p->pi_out_l, n_frames);
+        piorp = (sample_t *) jack_port_get_buffer(p->pi_out_r, n_frames);
+        pe1olp = (sample_t *) jack_port_get_buffer(p->pe1_out_l, n_frames);
+        pe1orp = (sample_t *) jack_port_get_buffer(p->pe1_out_r, n_frames);
+        pe2olp = (sample_t *) jack_port_get_buffer(p->pe2_out_l, n_frames);
+        pe2orp = (sample_t *) jack_port_get_buffer(p->pe2_out_r, n_frames);
+        pe3olp = (sample_t *) jack_port_get_buffer(p->pe3_out_l, n_frames);
+        pe3orp = (sample_t *) jack_port_get_buffer(p->pe3_out_r, n_frames);
+        plilp = (sample_t *) jack_port_get_buffer(p->pl_in_l, n_frames);
+        plirp = (sample_t *) jack_port_get_buffer(p->pl_in_r, n_frames);
+        prilp = (sample_t *) jack_port_get_buffer(p->pr_in_l, n_frames);
+        prirp = (sample_t *) jack_port_get_buffer(p->pr_in_r, n_frames);
+        piilp = (sample_t *) jack_port_get_buffer(p->pi_in_l, n_frames);
+        piirp = (sample_t *) jack_port_get_buffer(p->pi_in_r, n_frames);
+        peilp = (sample_t *) jack_port_get_buffer(p->pe_in_l, n_frames);
+        peirp = (sample_t *) jack_port_get_buffer(p->pe_in_r, n_frames);
+        ol_buffer = (sample_t *) jack_port_get_buffer(p->output_in_l, n_frames);
+        or_buffer = (sample_t *) jack_port_get_buffer(p->output_in_r, n_frames);
+        mol_buffer = (sample_t *) jack_port_get_buffer(p->monitor_output_in_l, n_frames);
+        mor_buffer = (sample_t *) jack_port_get_buffer(p->monitor_output_in_r, n_frames);
     }
 
-    mic_process_start_all(mics, nframes);
-    xlplayer_read_start_all(players, nframes, players_roster);
-    xlplayer_read_start_all(plr_j, nframes, plr_j_roster);
+    memcpy(mol_buffer, ol_buffer, n_frames * sizeof (sample_t));
+    memcpy(mor_buffer, or_buffer, n_frames * sizeof (sample_t));
+
+    audio_feed_supply_audio(ol_buffer, or_buffer, n_frames);
+
+    mic_process_start_all(mics, n_frames);
+    xlplayer_read_start_all(players, n_frames, players_roster);
+    xlplayer_read_start_all(plr_j, n_frames, plr_j_roster);
 
     /* there are four mixer modes with a lot of shared code */
     /* to keep things smaller and more maintainable macros have been used */
     if (simple_mixer == FALSE && mixermode == NO_PHONE)  /* Fully featured mixer code */
         {
-        memset(lps_buffer, 0, nframes * sizeof (sample_t)); /* send silence to VOIP */
-        memset(rps_buffer, 0, nframes * sizeof (sample_t));
-        for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
+        memset(lps_buffer, 0, n_frames * sizeof (sample_t)); /* send silence to VOIP */
+        memset(rps_buffer, 0, n_frames * sizeof (sample_t));
+        for(samples_todo = n_frames; samples_todo--; lap++, rap++, lsp++, rsp++,
                     dilp++, dirp++, dolp++, dorp++, aap++,
                     plolp++, plorp++, prolp++, prorp++, piolp++, piorp++,
                     pe1olp++, pe1orp++, pe2olp++, pe2orp++, pe3olp++, pe3orp++,
@@ -759,7 +770,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
     else
         if (simple_mixer == FALSE && mixermode == PHONE_PUBLIC)
             {
-            for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, aap++,
+            for(samples_todo = n_frames; samples_todo--; lap++, rap++, lsp++, rsp++, aap++,
                     lpsp++, rpsp++, lprp++, rprp++, dilp++, dirp++, dolp++, dorp++,
                     plolp++, plorp++, prolp++, prorp++, piolp++, piorp++,
                     pe1olp++, pe1orp++, pe2olp++, pe2orp++, pe3olp++, pe3orp++,
@@ -838,7 +849,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
         else
             if (simple_mixer == FALSE && mixermode == PHONE_PRIVATE && mic_on == 0)
                 {
-                for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
+                for(samples_todo = n_frames; samples_todo--; lap++, rap++, lsp++, rsp++,
                     lpsp++, rpsp++, lprp++, rprp++, dilp++, dirp++, dolp++, dorp++, aap++,
                     plolp++, plorp++, prolp++, prorp++, piolp++, piorp++,
                     pe1olp++, pe1orp++, pe2olp++, pe2orp++, pe3olp++, pe3orp++,
@@ -912,7 +923,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
             else
                 if (simple_mixer == FALSE && mixermode == PHONE_PRIVATE) /* note: mic is on */
                     {
-                    for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
+                    for(samples_todo = n_frames; samples_todo--; lap++, rap++, lsp++, rsp++,
                             lpsp++, rpsp++, dilp++, dirp++, dolp++, dorp++, aap++,
                             plolp++, plorp++, prolp++, prorp++, piolp++, piorp++,
                             pe1olp++, pe1orp++, pe2olp++, pe2orp++, pe3olp++, pe3orp++,
@@ -991,7 +1002,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
 
                         if (la || ls)
                             {
-                            samples_todo = nframes;
+                            samples_todo = n_frames;
                             while (samples_todo--)
                                 {
                                 xlplayer_read_next(plr_l);
@@ -1008,17 +1019,17 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
                                 }
                             }
 
-                        memset(al_buffer, 0, nframes * sizeof (sample_t));
+                        memset(al_buffer, 0, n_frames * sizeof (sample_t));
 
                         if (!la)
                             {
-                            memset(la_buffer, 0, nframes * sizeof (sample_t));
-                            memset(ra_buffer, 0, nframes * sizeof (sample_t));
+                            memset(la_buffer, 0, n_frames * sizeof (sample_t));
+                            memset(ra_buffer, 0, n_frames * sizeof (sample_t));
                             }
                         if (!ls)
                             {
-                            memset(ls_buffer, 0, nframes * sizeof (sample_t));
-                            memset(rs_buffer, 0, nframes * sizeof (sample_t));
+                            memset(ls_buffer, 0, n_frames * sizeof (sample_t));
+                            memset(rs_buffer, 0, n_frames * sizeof (sample_t));
                             }
                         }
                     else
@@ -1031,6 +1042,7 @@ int mixer_process_audio(jack_nframes_t nframes, void *arg)
             jack_ringbuffer_write(r128_rbuf, (char *)r128_buf, r128_bytes);
     }
 
+    g.jack_timeout = 0;
     return 0;
     }
 
