@@ -26,3 +26,5 @@ int mixer_healthcheck();
 int mixer_process_audio(jack_nframes_t n_frames, void *arg);
 void mixer_stop_players();
 int mixer_new_buffer_size(jack_nframes_t n_frames);
+void mixer_increment_port_connection_count();
+void mixer_new_port_of_interest(jack_port_id_t);
