@@ -1,6 +1,6 @@
 /*
 #   recorder.c: the recording part of the streaming module of idjc
-#   Copyright (C) 2007-2009 Stephen Fairchild (s-fairchild@users.sourceforge.net)
+#   Copyright (C) 2007-2025 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ static const size_t rb_n_samples = 10000;       /* maximum number of samples to
 static const size_t audio_buffer_elements = 256;
 
 #if 0
-static void recorder_write_ogg_metaheader(struct recorder *self)
+static void write_ogg_metaheader(struct recorder *self)
     {
     struct encoder *encoder = self->encoder_op->encoder;
     struct loe_data *s = encoder->encoder_private;
@@ -56,7 +56,7 @@ static void recorder_write_ogg_metaheader(struct recorder *self)
         fwrite(ogp->body, ogp->body_len, 1, self->fp);
         if (ferror(self->fp))
             {
-            fprintf(stderr, "recorder_write_ogg_metaheader: error writing the header\n");
+            fprintf(stderr, "recorder: write_ogg_metaheader: error writing the header\n");
             }
         }
 
@@ -119,9 +119,57 @@ static void recorder_write_ogg_metaheader(struct recorder *self)
     vorbis_comment_clear(&vc);
     vorbis_info_clear(&vi);
     }
-#endif /* recorder_write_ogg_metaheader */
+#endif /* write_ogg_metaheader */
 
-static int recorder_write_id3_tag(struct recorder *self, FILE *fp)
+static int create_cuesheet(struct recorder *self)
+    {
+    struct metadata_item *mi;
+    FILE *fp;
+    int i, mm, ss, ff;
+    const char *type;
+
+    if (!strcmp(".mp3", self->pathname + strlen(self->pathname) - 4))
+        type = "MP3";
+    else
+        type = "WAVE";
+
+    if (!(fp = fopen(self->cuepathname, "wb")))
+        {
+        fprintf(stderr, "recorder: create_cuesheet failed to open cue sheet file for writing\n");
+        return FAILED;
+        }
+
+    fprintf(fp, "TITLE \"%s\"\r\n", self->timestamp);
+    fprintf(fp, "PERFORMER \"Recorded with IDJC\"\r\n");
+    fprintf(fp, "FILE \"%s\" %s\r\n", strrchr(self->pathname, '/') + 1, type);
+
+    for (i = 1, mi = self->mi_first; mi; i++, mi = mi->next)
+        {
+        fprintf(fp, "  TRACK %02d AUDIO\r\n", i);
+        if (mi->title[0])
+            fprintf(fp, "    TITLE \"%s\"\r\n", mi->title);
+        if (mi->artist[0])
+            fprintf(fp, "    PERFORMER \"%s\"\r\n", mi->artist);
+        if (mi->album[0])
+            fprintf(fp, "    REM ALBUM \"%s\"\r\n", mi->album);
+
+        /* the first index must be zero - it's in the cue file standard */
+        if (i > 1)
+            {
+            mm = mi->time_offset / 60000;
+            ss = mi->time_offset / 1000 % 60;
+            ff = mi->time_offset % 1000 * 75 / 1000;
+            }
+        else
+            mm = ss =ff = 0;
+        fprintf(fp, "    INDEX 01 %02d:%02d:%02d\r\n", mm, ss, ff);
+        }
+
+    fclose(fp);
+    return SUCCEEDED;
+    }
+
+static int write_id3_tag(struct recorder *self, FILE *fp)
     {
     struct metadata_item *mi;
     struct id3_tag *tag;
@@ -150,49 +198,7 @@ static int recorder_write_id3_tag(struct recorder *self, FILE *fp)
     return SUCCEEDED;
     }
 
-static int recorder_create_mp3_cuesheet(struct recorder *self)
-    {
-    struct metadata_item *mi;
-    FILE *fp;
-    int i, mm, ss, ff;
-
-    if (!(fp = fopen(self->cuepathname, "wb")))
-        {
-        fprintf(stderr, "recorder_write_mp3_cue_sheet: failed to open cue sheet file for writing\n");
-        return FAILED;
-        }
-
-    fprintf(fp, "TITLE \"%s\"\r\n", self->timestamp);
-    fprintf(fp, "PERFORMER \"Recorded with IDJC\"\r\n");
-    fprintf(fp, "FILE \"%s\" MP3\r\n", strrchr(self->pathname, '/') + 1);
-
-    for (i = 1, mi = self->mi_first; mi; i++, mi = mi->next)
-        {
-        fprintf(fp, "  TRACK %02d AUDIO\r\n", i);
-        if (mi->title[0])
-            fprintf(fp, "    TITLE \"%s\"\r\n", mi->title);
-        if (mi->artist[0])
-            fprintf(fp, "    PERFORMER \"%s\"\r\n", mi->artist);
-        if (mi->album[0])
-            fprintf(fp, "    REM ALBUM \"%s\"\r\n", mi->album);
-
-        /* the first index must be zero - it's in the cue file standard */
-        if (i > 1)
-            {
-            mm = mi->time_offset / 60000;
-            ss = mi->time_offset / 1000 % 60;
-            ff = mi->time_offset % 1000 * 75 / 1000;
-            }
-        else
-            mm = ss =ff = 0;
-        fprintf(fp, "    INDEX 01 %02d:%02d:%02d\r\n", mm, ss, ff);
-        }
-
-    fclose(fp);
-    return SUCCEEDED;
-    }
-
-static int recorder_write_xing_tag(struct recorder *self, FILE *fp)
+static int write_xing_tag(struct recorder *self, FILE *fp)
     {
     int mpeg1_f, mono_f;
     int xing_offset, initial_offset;
@@ -202,9 +208,6 @@ static int recorder_write_xing_tag(struct recorder *self, FILE *fp)
     unsigned char seek_table[100], *ptr;
     struct metadata_item2 *mi2;
 
-    if (!self->include_xing_tag)
-        return SUCCEEDED;
-
     if (self->mi2_first == NULL)
         {
         fprintf(stderr, "recorder_write_xing_tag: no metadata collected, skipping vbr tag\n");
@@ -279,7 +282,7 @@ static int recorder_write_xing_tag(struct recorder *self, FILE *fp)
     return SUCCEEDED;
     }
 
-static void recorder_apply_mp3_tags(struct recorder *self)
+static void apply_tags(struct recorder *self)
     {
     char *tmpname;
     FILE *fpr, *fpw;
@@ -288,20 +291,20 @@ static void recorder_apply_mp3_tags(struct recorder *self)
 
     if (!(tmpname = malloc(strlen(self->pathname) + 5)))
         {
-        fprintf(stderr, "recorder_apply_mp3_tags: malloc failure\n");
+        fprintf(stderr, "recorder: apply_mp3_tags: malloc failure\n");
         return;
         }
     strcpy(tmpname, self->pathname);
     strcat(tmpname, ".tmp");
     if (!(fpw = fopen(tmpname, "w+")))
         {
-        fprintf(stderr, "recorder_apply_mp3_tags: failed to open temporary file\n");
+        fprintf(stderr, "recorder: apply_mp3_tags: failed to open temporary file\n");
         free(tmpname);
         return;
         }
     if (!(fpr = fopen(self->pathname, "r")))
         {
-        fprintf(stderr, "recorder_apply_mp3_tags: failed to open the mp3 file\n");
+        fprintf(stderr, "recorder: apply_mp3_tags: failed to open the mp3 file\n");
         fclose(fpw);
         unlink(tmpname);
         free(tmpname);
@@ -319,15 +322,22 @@ static void recorder_apply_mp3_tags(struct recorder *self)
         }
     rewind(fpr);
 
-    if (!(recorder_write_id3_tag(self, fpw) && recorder_write_xing_tag(self, fpw)))
-        {
-        fprintf(stderr, "recorder_apply_mp3_tags: failed to tag the mp3 file\n");
-        fclose(fpr);
-        fclose(fpw);
-        unlink(tmpname);
-        free(tmpname);
-        return;
+    {
+        int ret1 = TRUE, ret2 = TRUE;
+
+        if (self->apply_id3_tag_f)
+            ret1 = write_id3_tag(self, fpw);
+        if (self->apply_xing_tag_f)
+            ret2 = write_xing_tag(self, fpw);
+        if (!(ret1 && ret2)) {
+            fprintf(stderr, "recorder: apply_mp3_tags: failed to tag the mp3 file\n");
+            fclose(fpr);
+            fclose(fpw);
+            unlink(tmpname);
+            free(tmpname);
+            return;
         }
+    }
     for (;;)             /* copy the mp3 file's data onto the end of the tagged file */
         {
         bytes = fread(buffer, 1, 2048, fpr);
@@ -335,7 +345,7 @@ static void recorder_apply_mp3_tags(struct recorder *self)
             break;
         if (!(fwrite(buffer, bytes, 1, fpw)))
             {
-            fprintf(stderr, "recorder_apply_mp3_tags: error copying the mp3 file\n");
+            fprintf(stderr, "recorder: apply_mp3_tags: error copying the mp3 file\n");
             fclose(fpr);
             fclose(fpw);
             unlink(tmpname);
@@ -347,21 +357,21 @@ static void recorder_apply_mp3_tags(struct recorder *self)
     fclose(fpw);
     if (rename(tmpname, self->pathname))
         {
-        fprintf(stderr, "recorder_apply_mp3_tags: failed to rename the temporary file\n");
+        fprintf(stderr, "recorder: apply_mp3_tags: failed to rename the temporary file\n");
         free(tmpname);
         return;
         }
     free(tmpname);
-    fprintf(stderr, "recorder_apply_mp3_tags: successfully tagged the mp3 file\n");
+    fprintf(stderr, "recorder: apply_mp3_tags: successfully tagged the mp3 file\n");
     }
 
-static void recorder_append_metadata2(struct recorder *self, struct encoder_op_packet *packet)
+static void append_metadata2(struct recorder *self, struct encoder_op_packet *packet)
     {
     struct metadata_item2 *mi2;
 
     if (!(mi2 = calloc(1, sizeof (struct metadata_item2))))
         {
-        fprintf(stderr, "recorder_append_metadata2: malloc failure\n");
+        fprintf(stderr, "recorder: append_metadata2: malloc failure\n");
         return;
         }
     if (!(self->mi2_first))
@@ -395,19 +405,19 @@ static void recorder_append_metadata2(struct recorder *self, struct encoder_op_p
         else
             free(mi2);
         }
-    if (packet && (packet->header.bit_rate != self->oldbitrate || packet->header.sample_rate != self->oldsamplerate) && (packet->header.flags & (PF_MP3 | PF_MP2 | PF_AAC | PF_AACP2)))
+    if (packet && (packet->header.bit_rate != self->oldbitrate || packet->header.sample_rate != self->oldsamplerate) && (packet->header.flags & (PF_MP3 | PF_MP2 | PF_AAC | PF_AACP)))
         {
         if (self->oldbitrate && self->oldsamplerate)
             {
             self->is_vbr = TRUE;
-            fprintf(stderr, "recorder_append_metadata2: the mp3 frame length altered\n");
+            fprintf(stderr, "recorder: append_metadata2: the mp3 frame length altered\n");
             }
         self->oldbitrate = packet->header.bit_rate;
         self->oldsamplerate = packet->header.sample_rate;
         }
     }
 
-static void recorder_free_metadata2(struct recorder *self)
+static void free_metadata2(struct recorder *self)
     {
     struct metadata_item2 *mi2, *oldmi2;
 
@@ -421,7 +431,7 @@ static void recorder_free_metadata2(struct recorder *self)
     self->mi2_last = NULL;
     }
 
-static void recorder_display_logged_metadata2(struct metadata_item2 *mi2)
+static void display_logged_metadata2(struct metadata_item2 *mi2)
     {
     if (mi2)
         {
@@ -434,7 +444,7 @@ static void recorder_display_logged_metadata2(struct metadata_item2 *mi2)
         fprintf(stderr, "No start position for the stream was logged!\n");
     }
 
-static void recorder_append_metadata(struct recorder *self, struct encoder_op_packet *packet)
+static void append_metadata(struct recorder *self, struct encoder_op_packet *packet)
     {
     struct metadata_item *mi;
     char *artist, *title, *album, *stringp;
@@ -454,13 +464,13 @@ static void recorder_append_metadata(struct recorder *self, struct encoder_op_pa
                 && !strcmp(self->mi_last->title, title)
                 && !strcmp(self->mi_last->album, album))
         {
-        fprintf(stderr, "recorder_append_metadata: duplicate artist-title, skipping\n");
+        fprintf(stderr, "recorder: append_metadata: duplicate artist-title, skipping\n");
         return;
         }
 
     if (!(mi = calloc(1, sizeof (struct metadata_item))))
         {
-        fprintf(stderr, "recorder_append_metadata: malloc failure\n");
+        fprintf(stderr, "recorder: append_metadata: malloc failure\n");
         return;
         }
 
@@ -493,7 +503,7 @@ static void recorder_append_metadata(struct recorder *self, struct encoder_op_pa
         }
     }
 
-static void recorder_free_metadata(struct recorder *self)
+static void free_metadata(struct recorder *self)
     {
     struct metadata_item *mi, *oldmi;
 
@@ -510,7 +520,7 @@ static void recorder_free_metadata(struct recorder *self)
     self->mi_last = NULL;
     }
 
-static void recorder_display_logged_metadata(struct metadata_item *mi)
+static void display_logged_metadata(struct metadata_item *mi)
     {
     if (mi)
         {
@@ -610,9 +620,9 @@ static void *recorder_main(void *args)
                         {
                         if (packet->header.serial >= self->initial_serial)
                             {
-                            if ((packet->header.flags & PF_INITIAL) && self->id3_mode)
-                                recorder_append_metadata2(self, packet);
-                            if (packet->header.flags & (PF_WEBM | PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP2))
+                            if ((packet->header.flags & PF_INITIAL) && self->apply_xing_tag_f)
+                                append_metadata2(self, packet);
+                            if (packet->header.flags & (PF_WEBM | PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP))
                                 {
                                 if (packet->header.data_size != fwrite(packet->data, 1, packet->header.data_size, self->fp))
                                     {
@@ -637,8 +647,8 @@ static void *recorder_main(void *args)
                                     }
                                 }
                             }
-                        if (packet->header.flags & PF_METADATA)
-                            recorder_append_metadata(self, packet);
+                        if (packet->header.flags & PF_METADATA && (self->apply_id3_tag_f || self->produce_cue_sheet_f))
+                            append_metadata(self, packet);
                         encoder_client_free_packet(packet);
                         }
                     if (self->stop_request)
@@ -660,10 +670,13 @@ static void *recorder_main(void *args)
                     self->record_mode = RM_STOPPING;
                 else
                     {
-                    while ((nbytes = jack_ringbuffer_read(self->afdata.input_rb[1], self->right, audio_buffer_elements * sizeof (sample_t))))
-                        {
-                        jack_ringbuffer_read(self->afdata.input_rb[0], self->left, nbytes);
-                        }
+                    if (self->initial_serial == -1) {
+                        while ((nbytes = jack_ringbuffer_read(self->afdata.input_rb[1], self->right, audio_buffer_elements * sizeof (sample_t))))
+                            jack_ringbuffer_read(self->afdata.input_rb[0], self->left, nbytes);
+                    } else {
+                        if ((packet = encoder_client_get_packet(self->encoder_op)))
+                            encoder_client_free_packet(packet);
+                    }
 
                     if (self->unpause_request)
                         {
@@ -693,17 +706,22 @@ static void *recorder_main(void *args)
                     }
                 else
                     {
-                    if (self->id3_mode)
-                        {
-                        recorder_append_metadata(self, NULL);
-                        recorder_append_metadata2(self, NULL);
-                        recorder_display_logged_metadata(self->mi_first);
-                        recorder_display_logged_metadata2(self->mi2_first);
-                        recorder_apply_mp3_tags(self);
-                        recorder_create_mp3_cuesheet(self);
-                        recorder_free_metadata(self);
-                        recorder_free_metadata2(self);
-                        }
+                    if (self->apply_xing_tag_f) {
+                        append_metadata2(self, NULL);
+                        display_logged_metadata2(self->mi2_first);
+                    }
+                    if (self->apply_id3_tag_f) {
+                        append_metadata(self, NULL);
+                        display_logged_metadata(self->mi_first);
+                    }
+                    if (self->apply_xing_tag_f || self->apply_id3_tag_f)
+                        apply_tags(self);
+                    if (self->produce_cue_sheet_f)
+                        create_cuesheet(self);
+                    if (self->apply_id3_tag_f || self->produce_cue_sheet_f)
+                        free_metadata(self);
+                    if (self->apply_xing_tag_f)
+                        free_metadata2(self);
                     encoder_unregister_client(self->encoder_op);
                     }
 
@@ -714,8 +732,9 @@ static void *recorder_main(void *args)
                 memset(self->first_mp3_header, 0x00, 4);
                 self->oldbitrate = 0;
                 self->oldsamplerate = 0;
-                self->id3_mode = FALSE;
-                self->include_xing_tag = FALSE;
+                self->produce_cue_sheet_f = FALSE;
+                self->apply_id3_tag_f = FALSE;
+                self->apply_xing_tag_f = FALSE;
                 self->is_vbr = FALSE;
                 self->recording_length_s = 0;
                 self->recording_length_ms = 0;
@@ -844,17 +863,18 @@ int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *oth
                     switch (df->codec) {
                         case ENCODER_CODEC_MP3:
                             file_extension = ".mp3";
-                            self->id3_mode = TRUE;
-                            self->include_xing_tag = TRUE;
+                            self->apply_id3_tag_f = TRUE;
+                            self->apply_xing_tag_f = TRUE;
+                            self->produce_cue_sheet_f = TRUE;
                             break;
                         case ENCODER_CODEC_MP2:
                             file_extension = ".mp2";
-                            self->id3_mode = TRUE;
+                            self->produce_cue_sheet_f = TRUE;
                             break;
                         case ENCODER_CODEC_AAC:
-                        case ENCODER_CODEC_AACPLUSV2:
+                        case ENCODER_CODEC_AACPLUS:
                             file_extension = ".aac";
-                            self->id3_mode = TRUE;
+                            self->produce_cue_sheet_f = TRUE;
                             break;
                         case ENCODER_CODEC_UNHANDLED:
                         default:
@@ -971,7 +991,7 @@ int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *oth
         fprintf(stderr, "recorder_start: in FLAC mode\n");
         }
     //if (file_extension == ".oga")
-    //   recorder_write_ogg_metaheader(self);
+    //   write_ogg_metaheader(self);
     pthread_mutex_lock(&self->mode_mutex);
     if (self->pause_request == TRUE)
         self->record_mode = RM_PAUSED;
