@@ -1,6 +1,6 @@
 /*
 #   recorder.h: the recording part of the streaming module of idjc
-#   Copyright (C) 2007-2009 Stephen Fairchild (s-fairchild@users.sourceforge.net)
+#   Copyright (C) 2007-2025 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -89,9 +89,10 @@ struct recorder
     struct metadata_item *mi_last;
     struct metadata_item2 *mi2_first;    /* log mp3 block sizes and durations */
     struct metadata_item2 *mi2_last;
-    int id3_mode;                /* when set applies an id3 tag */
-    int include_xing_tag;        /* if true a xing/info tag is to be written */
-    int is_vbr;                  /* frame length changed */
+    int produce_cue_sheet_f;   /* set to true to request a cue sheet */
+    int apply_id3_tag_f;       /* if true an id3 tag is produced */
+    int apply_xing_tag_f;      /* if true a xing/info tag is to be written */
+    int is_vbr;                /* frame length changed */
     unsigned oldbitrate;
     unsigned oldsamplerate;
     char first_mp3_header[4];
