@@ -29,7 +29,7 @@
 #include "sourceclient.h"
 #include "kvpparse.h"
 #include "live_ogg_encoder.h"
-#include "live_aac_encoder.h"
+#include "live_aac_encoder2.h"
 #include "sig.h"
 #include "main.h"
 
@@ -149,6 +149,7 @@ static struct kvpdict kvpdict[] = {
     { "resample_quality", &ev.resample_quality, NULL },
     { "family",           &ev.family, NULL },
     { "codec",            &ev.codec, NULL },
+    { "profile",          &ev.profile, NULL },
     { "bitrate",          &ev.bitrate, NULL },
     { "variability",      &ev.variability, NULL },
     { "bitwidth",         &ev.bitwidth, NULL },
@@ -200,6 +201,7 @@ static GHashTable *ht;
 static struct commandmap commandmap[] = {
     { "jack_samplerate_request", audio_feed_jack_samplerate_request, NULL },
     { "encoder_lame_availability", encoder_init_lame, NULL},
+    { "encoder_aac_profiles", encoder_aac_profiles, NULL},
     { "get_report", get_report, NULL },
     { "encoder_start", encoder_start, &ev },
     { "encoder_stop", encoder_stop, NULL },
@@ -213,6 +215,8 @@ static struct commandmap commandmap[] = {
     { "server_connect", streamer_connect, &sv },
     { "server_disconnect", streamer_disconnect, NULL },
     { "initiate_fade", encoder_initiate_fade, NULL },
+    { "random_noise_on", audio_feed_random_noise_on, NULL },
+    { "random_noise_off", audio_feed_random_noise_on, NULL },
     { NULL, NULL, NULL } };
 
 static void sourceclient_cleanup()
