@@ -114,7 +114,7 @@ static void *streamer_main(void *args)
                             /* determine how much audio to hold in the send buffer */
                             self->max_shout_queue = (shout_buffer_seconds * ((br > 1000) ? br / 1000 : br)) << 7;
                             }
-                        if (packet->header.flags & (PF_WEBM | PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP2))
+                        if (packet->header.flags & (PF_WEBM | PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP))
                             {
                             if ((packet->header.flags & (PF_HEADER | PF_FINAL)) || shout_queuelen(self->shout) < self->max_shout_queue)
                                 data_size = packet->header.data_size;
@@ -172,7 +172,7 @@ static void *streamer_main(void *args)
                     }
                 break;
             case SM_DISCONNECTING:
-                fprintf(stderr, "streamer_main: disconencting from server\n");
+                fprintf(stderr, "streamer_main: disconnecting from server\n");
                 shout_close(self->shout);
                 shout_free(self->shout);
                 shout_metadata_free(self->shout_meta);
@@ -257,7 +257,7 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
                         failed = TRUE;
 #endif /* SHOUT_FORMAT_AAC */
                         break;
-                    case ENCODER_CODEC_AACPLUSV2:
+                    case ENCODER_CODEC_AACPLUS:
 #ifdef SHOUT_FORMAT_AACPLUS
                         data_format = SHOUT_FORMAT_AACPLUS;
 #else
@@ -283,6 +283,7 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
                 break;
 
             case ENCODER_FAMILY_UNHANDLED:
+            default:
                 failed = TRUE;
             }
 
