@@ -37,6 +37,7 @@
 
 #include "fade.h"
 #include "smoothing.h"
+#include "iswr.h"
 
 enum command_t {CMD_COMPLETE, CMD_PLAY, CMD_EJECT, CMD_CLEANUP, CMD_THREADEXIT, CMD_PLAYMANY};
 
@@ -111,10 +112,10 @@ struct xlplayer
     int up;                             /* set to true when the player is fully initialised */
     double pbspeed;                     /* the playback speed as a factor */
     float newpbspeed;                   /* the value the above is updated with */
-    SRC_STATE *pbspeed_conv_l;          /* libsamplerate handle for playback speed control - left channel */
-    SRC_STATE *pbspeed_conv_r;
-    SRC_STATE *pbspeed_conv_lf;         /* as above but for fade buffer */
-    SRC_STATE *pbspeed_conv_rf;
+    ISWR_STATE *pbspeed_conv_l;          /* libsamplerate handle for playback speed control - left channel */
+    ISWR_STATE *pbspeed_conv_r;
+    ISWR_STATE *pbspeed_conv_lf;         /* as above but for fade buffer */
+    ISWR_STATE *pbspeed_conv_rf;
     float *pbsrb_l;                     /* input buffers for the playback speed converter */
     float *pbsrb_r;
     float *pbsrb_lf;
