@@ -698,7 +698,7 @@ class AnnounceMessageDialog(MessageDialog):
         "which means they are listening the same amount of time behind the "
         "actual stream therefore without a delay IRC messages will appear to "
         "the listener many seconds ahead of the audio.\n\nThis setting will "
-        "help synchronise the track change with the message."))
+        "help synchronize the track change with the message."))
 
     def as_tuple(self):
         """Data extraction method."""
