@@ -1082,7 +1082,7 @@ class mixprefs:
         alarm_aud.show()
         set_tip(alarm_aud, _('This adjusts the sound level of the DJ alarm. '
         'Typically this should be set close to the dj audio level when using the \'%s\''
-        ' feature, otherwise a bit louder.' % _('Music Loudness Compensation')))
+        ' feature, otherwise a bit louder.' % _('Track Loudness Normalization')))
         aud_rs_hbox.pack_start(frame, False, False, 0)
         frame.show()
 
@@ -1309,7 +1309,7 @@ class mixprefs:
 
         # ReplayGain controls
 
-        frame = Gtk.Frame.new(" %s " % _('Player Loudness Normalization'))
+        frame = Gtk.Frame.new(" %s " % _('Track Loudness Normalization'))
         frame.set_border_width(3)
         outervbox.pack_start(frame, False, False, 0)
         vbox = Gtk.VBox()
