@@ -147,7 +147,7 @@ class ArgumentParserImplementation(metaclass=Singleton):
         if os.getenv("idjcdev"):
             sp_run.add_argument("-T", "--testing", dest="testing",
                     action="store_true",
-                    help=_("developer mode for backend testing"))
+                    help=_("developer mode for back-end testing"))
         sp_run.add_argument("-d", "--dialog", dest="dialog", nargs=1,
                 choices=("true", "false"),
                 help=_("""force the appearance or non-appearance of the
@@ -427,6 +427,8 @@ class ProfileManager(metaclass=Singleton):
             self._testing = args.testing
         except AttributeError:
             self._testing = False
+        if self.testing:
+            return
 
         if self._session_dir is None:
             # Not in session mode so do the profile init stuff.
@@ -690,7 +692,7 @@ class ProfileManager(metaclass=Singleton):
                      (session_type,
                       str(list(supported_sessions.values()))))
 
-        # The backend when started needs to know what session type we are using.
+        # The back-end when started needs to know what session type we are using.
         os.environ["session_type"] = session_type
 
         if re.match("^[a-zA-Z0-9_]+$", session_name) is None:
