@@ -18,6 +18,7 @@
 
 __all__ = ["ProfileDialog"]
 
+import os
 import atexit
 import gettext
 
@@ -46,6 +47,7 @@ from ..gtkstuff import timeout_add
 t = gettext.translation(FGlobs.package_name, FGlobs.localedir, fallback=True)
 _ = t.gettext
 
+SESSION = os.getenv("XDG_SESSION_TYPE", "x11")
 
 class ProfileEntry(Gtk.Entry):
     _allowed = (65056, 65361, 65363, 65365, 65288, 65289, 65535)
@@ -113,15 +115,16 @@ class NewProfileDialog(Gtk.Dialog):
                 # TC: data entry dialog label text.
                 _("Profile name"),
                 # TC: data entry dialog label text.
-                _("Icon"),
+                _("Icon") if SESSION != "wayland" else "",
                 # TC: data entry dialog label text.
                 _("Nickname"),
                 # TC: data entry dialog label text.
                 _("Description"))
         names = ("profile_entry", "icon_button", "nickname_entry",
                                                         "description_entry")
-        widgets = (ProfileEntry(), IconChooserButton(self._icon_dialog),
-                      Gtk.Entry(), Gtk.Entry())
+        icb = IconChooserButton(self._icon_dialog)
+        icb.set_no_show_all(SESSION == "wayland")
+        widgets = (ProfileEntry(), icb, Gtk.Entry(), Gtk.Entry())
 
         for i, (label, name, widget) in enumerate(zip(labels, names, widgets)):
             label = Gtk.Label.new(label)
@@ -244,9 +247,10 @@ class ProfileDialog(Gtk.Dialog, metaclass=ProfileSingleton):
         image.show()
         self.treeview.append_column(c0)
         c1 = Gtk.TreeViewColumn(_("Profile"))
-        c1.pack_start(pbrend, expand=False)
+        if SESSION != "wayland":
+            c1.pack_start(pbrend, expand=False)
+            c1.add_attribute(pbrend, "pixbuf", 0)
         c1.pack_start(strrend, expand=True)
-        c1.add_attribute(pbrend, "pixbuf", 0)
         c1.add_attribute(strrend, "text", 1)
         c1.set_spacing(2)
         self.treeview.append_column(c1)
