@@ -1969,13 +1969,14 @@ class MediaPane(Gtk.VBox):
         Step 1 Identifying database type.
         """
 
+        notify(_('Unrecognized database'))
         data = cursor.fetchall()
         if self.schema_test("tracks", data):
             request(('DESCRIBE tracks',), self._stage_2, self._fail_1)
         elif self.schema_test("album artist song", data):
             request(('DESCRIBE song',), self._stage_4, self._fail_1)
         else:
-            notify(_('Unrecognised database'))
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_2(self, acc, request, cursor, notify, rows):
@@ -1988,7 +1989,7 @@ class MediaPane(Gtk.VBox):
             request(("""ALTER TABLE tracks ADD FULLTEXT artist (artist,title,
                         album,filename)""",), self._stage_2a, self._fail_2)
         else:
-            notify(_('Unrecognised database'))
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_2a(self, acc, request, cursor, notify, rows):
@@ -2005,23 +2006,23 @@ class MediaPane(Gtk.VBox):
                                                             cursor.fetchall()):
             request(('DESCRIBE artist',), self._stage_5, self._fail_1)
         else:
-            notify('Unrecognised database')
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_5(self, acc, request, cursor, notify, rows):
         if self.schema_test("name prefix", cursor.fetchall()):
             request(('DESCRIBE artist',), self._stage_6, self._fail_1)
         else:
-            notify('Unrecognised database')
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_6(self, acc, request, cursor, notify, rows):
         if self.schema_test("name prefix", cursor.fetchall()):
-            notify('Found Ampache schema')
+            notify(_('Found Ampache schema'))
             request(("ALTER TABLE album ADD FULLTEXT idjc (name)",),
                                                 self._stage_7, self._fail_2)
         else:
-            notify('Unrecognised database')
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_7(self, acc, request, cursor, notify, rows):
@@ -2032,12 +2033,12 @@ class MediaPane(Gtk.VBox):
         request(("ALTER TABLE song ADD FULLTEXT idjc (title)",), self._stage_9,
                                                                 self._fail_2)
     def _stage_9(self, acc, request, cursor, notify, rows):
-        notify("Checking ampache type")
+        notify(_("Checking ampache type"))
         request(("DESCRIBE catalog",), self._stage_10, self._fail_2)
 
     def _stage_10(self, acc, request, cursor, notify, rows):
         if self.schema_test("path", cursor.fetchall()):
-            notify('Found Ampache pre 3.7 schema')
+            notify(_('Found Ampache pre 3.7 schema'))
             self._hand_over(AMPACHE)
         else:
             request(("DESCRIBE catalog_local",), self._stage_11, self._fail_2)
@@ -2046,19 +2047,19 @@ class MediaPane(Gtk.VBox):
         if self.schema_test("path", cursor.fetchall()):
             request(("DESCRIBE album",), self._stage_12, self._fail_2)
         else:
-            notify('Unrecognised database')
+            notify(_('Unrecognized database'))
             self._safe_disconnect()
 
     def _stage_12(self, acc, request, cursor, notify, rows):
         rslt = cursor.fetchall()
         if self.schema_test("disk_count", rslt):
-            notify('Found Ampache 7.0+ schema')
+            notify(_('Found Ampache 7.0+ schema'))
             self._hand_over(AMPACHE_7_0)
             return
         if self.schema_test("disk", rslt):
-            notify('Found Ampache 3.7+ pre 7.0 schema')
+            notify(_('Found Ampache 3.7+ pre 7.0 schema'))
             self._hand_over(AMPACHE_3_7)
             return
 
-        notify('Unrecognised database :(')
+        notify(_('Unrecognized database'))
         self._safe_disconnect()
